@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -250,6 +250,33 @@ class AutoscalingClient(AbstractClient):
 
     def CreateNotificationConfiguration(self, request):
         """本接口（CreateNotificationConfiguration）用于创建通知。
+        通知到 CMQ 主题或队列时，消息内容如下：
+        ```
+        {
+            "Service": "Tencent Cloud Auto Scaling",
+            "CreatedTime": "2021-10-11T10:15:11Z", // 活动创建时间
+            "AppId": "100000000",
+            "ActivityId": "asa-fznnvrja", // 伸缩活动ID
+            "AutoScalingGroupId": "asg-pc2oqu2z", // 伸缩组ID
+            "ActivityType": "SCALE_OUT",  // 伸缩活动类型
+            "StatusCode": "SUCCESSFUL",   // 伸缩活动结果
+            "Description": "Activity was launched in response to a difference between desired capacity and actual capacity,
+            scale out 1 instance(s).", // 伸缩活动描述
+            "StartTime": "2021-10-11T10:15:11Z",  // 活动开始时间
+            "EndTime": "2021-10-11T10:15:32Z",    // 活动结束时间
+            "DetailedStatusMessageSet": [ // 活动内部错误集合（非空不代表活动失败）
+                {
+                    "Code": "InvalidInstanceType",
+                    "Zone": "ap-guangzhou-2",
+                    "InstanceId": "",
+                    "InstanceChargeType": "POSTPAID_BY_HOUR",
+                    "SubnetId": "subnet-4t5mgeuu",
+                    "Message": "The specified instance type `S5.LARGE8` is invalid in `subnet-4t5mgeuu`, `ap-guangzhou-2`.",
+                    "InstanceType": "S5.LARGE8"
+                }
+            ]
+        }
+        ```
 
         :param request: Request instance for CreateNotificationConfiguration.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.CreateNotificationConfigurationRequest`
@@ -1067,7 +1094,7 @@ class AutoscalingClient(AbstractClient):
     def ModifyLoadBalancers(self, request):
         """本接口（ModifyLoadBalancers）用于修改伸缩组的负载均衡器。
 
-        * 本接口用于为伸缩组指定新的负载均衡器配置，采用“完全覆盖”风格，无论之前配置如何，统一按照接口参数配置为新的负载均衡器。
+        * 本接口用于为伸缩组指定新的负载均衡器配置，采用`完全覆盖`风格，无论之前配置如何，`统一按照接口参数配置为新的负载均衡器`。
         * 如果要为伸缩组清空负载均衡器，则在调用本接口时仅指定伸缩组ID，不指定具体负载均衡器。
         * 本接口会立即修改伸缩组的负载均衡器，并生成一个伸缩活动，异步修改存量实例的负载均衡器。
 
@@ -1098,6 +1125,7 @@ class AutoscalingClient(AbstractClient):
 
     def ModifyNotificationConfiguration(self, request):
         """本接口（ModifyNotificationConfiguration）用于修改通知。
+        * 通知的接收端类型不支持修改。
 
         :param request: Request instance for ModifyNotificationConfiguration.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.ModifyNotificationConfigurationRequest`
@@ -1239,9 +1267,73 @@ class AutoscalingClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ScaleInInstances(self, request):
+        """为伸缩组指定数量缩容实例，返回缩容活动的 ActivityId。
+        * 伸缩组需要未处于活动中
+        * 根据伸缩组的`TerminationPolicies`策略，选择被缩容的实例，可参考[缩容处理](https://cloud.tencent.com/document/product/377/8563)
+        * 接口只会选择`IN_SERVICE`实例缩容，如果需要缩容其他状态实例，可以使用 [DetachInstances](https://cloud.tencent.com/document/api/377/20436) 或 [RemoveInstances](https://cloud.tencent.com/document/api/377/20431) 接口
+        * 接口会减少期望实例数，新的期望实例数需要大于等于最小实例数
+        * 缩容如果失败或者部分成功，最后期望实例数只会扣减实际缩容成功的实例数量
+
+        :param request: Request instance for ScaleInInstances.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ScaleInInstancesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ScaleInInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ScaleInInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ScaleInInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def ScaleOutInstances(self, request):
+        """为伸缩组指定数量扩容实例，返回扩容活动的 ActivityId。
+        * 伸缩组需要未处于活动中
+        * 接口会增加期望实例数，新的期望实例数需要小于等于最大实例数
+        * 扩容如果失败或者部分成功，最后期望实例数只会增加实际成功的实例数量
+
+        :param request: Request instance for ScaleOutInstances.
+        :type request: :class:`tencentcloud.autoscaling.v20180419.models.ScaleOutInstancesRequest`
+        :rtype: :class:`tencentcloud.autoscaling.v20180419.models.ScaleOutInstancesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ScaleOutInstances", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ScaleOutInstancesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def SetInstancesProtection(self, request):
-        """本接口（SetInstancesProtection）用于设置实例移除保护。
-        子机设置为移除保护之后，当发生不健康替换、报警策略、期望值变更等触发缩容时，将不对此子机缩容操作。
+        """本接口（SetInstancesProtection）用于设置实例保护。
+        实例设置保护之后，当发生不健康替换、报警策略、期望值变更等触发缩容时，将不对此实例缩容操作。
 
         :param request: Request instance for SetInstancesProtection.
         :type request: :class:`tencentcloud.autoscaling.v20180419.models.SetInstancesProtectionRequest`
